@@ -1,4 +1,22 @@
-#define _USE_MATH_DEFINES // for MSVC to define M_PI etc.
+/*
+ * CalcMySky - a simulator of light scattering in planetary atmospheres
+ * Copyright © 2025 Ruslan Kabatsayev
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
+ */
+
 #include <iostream>
 #include <iterator>
 #include <sstream>
@@ -34,6 +52,8 @@ using glm::vec2;
 using glm::vec4;
 std::vector<glm::vec4> eclipsedDoubleScatteringAccumulatorTexture;
 
+static const QString currentPhaseFunctionStub = "vec4 currentPhaseFunction(float dotViewSun) { return vec4(3.4028235e38); }\n";
+
 void saveIrradiance(const unsigned scatteringOrder, const unsigned texIndex)
 {
     if(scatteringOrder==atmo.scatteringOrdersToCompute)
@@ -570,8 +590,7 @@ void computeScatteringOrder1AndScatteringDensityOrder2(const unsigned texIndex)
     std::unique_ptr<QOpenGLShaderProgram> program;
     {
         // Make a stub for current phase function. It's not used for ground radiance, but we need it to avoid linking errors.
-        virtualSourceFiles[PHASE_FUNCTIONS_SHADER_FILENAME]=makePhaseFunctionsSrc()+
-            "vec4 currentPhaseFunction(float dotViewSun) { return vec4(3.4028235e38); }\n";
+        virtualSourceFiles[PHASE_FUNCTIONS_SHADER_FILENAME]=makePhaseFunctionsSrc()+currentPhaseFunctionStub;
 
         // Doing replacements instead of using uniforms is meant to
         //  1) Improve performance by statically avoiding branching
@@ -1255,7 +1274,7 @@ int main(int argc, char** argv)
             initConstHeader(atmo.allWavelengths[texIndex]);
             virtualSourceFiles[COMPUTE_TRANSMITTANCE_SHADER_FILENAME]=
                 makeTransmittanceComputeFunctionsSrc(atmo.allWavelengths[texIndex]);
-            virtualSourceFiles[PHASE_FUNCTIONS_SHADER_FILENAME]=makePhaseFunctionsSrc();
+            virtualSourceFiles[PHASE_FUNCTIONS_SHADER_FILENAME]=makePhaseFunctionsSrc()+currentPhaseFunctionStub;
             virtualSourceFiles[TOTAL_SCATTERING_COEFFICIENT_SHADER_FILENAME]=makeTotalScatteringCoefSrc();
             virtualHeaderFiles[RADIANCE_TO_LUMINANCE_HEADER_FILENAME]="const mat4 radianceToLuminance=" +
                                                   toString(radianceToLuminance(texIndex, atmo.allWavelengths)) + ";\n";
