@@ -1,3 +1,22 @@
+/*
+ * CalcMySky - a simulator of light scattering in planetary atmospheres
+ * Copyright © 2025 Ruslan Kabatsayev
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
+ */
+
 #include "GLWidget.hpp"
 #include <chrono>
 #include <QKeyEvent>
@@ -5,7 +24,6 @@
 #include <QFileDialog>
 #include <QMessageBox>
 #include <QSurfaceFormat>
-#define GLM_ENABLE_EXPERIMENTAL
 #include <glm/gtx/transform.hpp>
 #include "../common/util.hpp"
 #include "../common/const.hpp"
@@ -15,12 +33,12 @@
 #include "GLSLCosineQualityChecker.hpp"
 #include "BlueNoiseTriangleRemapped.hpp"
 
-static QPoint position(QMouseEvent* event)
+static QPointF position(QMouseEvent* event, double scale)
 {
 #if QT_VERSION < QT_VERSION_CHECK(6,0,0)
-    return event->pos();
+    return QPointF(event->pos()) * scale;
 #else
-    return event->position().toPoint();
+    return event->position().toPoint() * scale;
 #endif
 }
 
@@ -643,10 +661,10 @@ void GLWidget::paintGL()
         updateSpectralRadiance(lastRadianceCapturePosition);
 }
 
-void GLWidget::resizeGL(int w, int h)
+void GLWidget::resizeGL(int, int)
 {
     if(!renderer) return;
-    renderer->resizeEvent(w,h);
+    renderer->resizeEvent(width(),height());
     makeGlareRenderTarget();
 }
 
@@ -710,7 +728,7 @@ void GLWidget::mouseMoveEvent(QMouseEvent* event)
         return;
     }
 
-    const auto pos = position(event);
+    const auto pos = position(event, devicePixelRatioF());
     switch(dragMode_)
     {
     case DragMode::Sun:
@@ -787,7 +805,7 @@ void GLWidget::mousePressEvent(QMouseEvent* event)
         return;
     }
 
-    const auto pos = position(event);
+    const auto pos = position(event, devicePixelRatioF());
     if(event->modifiers() & Qt::ControlModifier)
         setDragMode(DragMode::Sun, pos.x(), pos.y());
     else
@@ -841,6 +859,16 @@ void GLWidget::saveScreenshot()
     }
 }
 
+int GLWidget::width() const
+{
+    return QWidget::width() * devicePixelRatioF();
+}
+
+int GLWidget::height() const
+{
+    return QWidget::height() * devicePixelRatioF();
+}
+
 void GLWidget::setupBuffers()
 {
     if(!vao_)
